﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using ThinkGeo.MapSuite.Core;
using System.IO;
using ThinkGeo.MapSuite.DesktopEdition;

namespace QueryToolsTest
{
    public partial class Form1 : Form
    {
        private string INmapbase = @"C:\JTACGIS";

        public Form1()
        {
            InitializeComponent();
            this.Load += new EventHandler(Form1_Load);
			this.btnClickMe.Click += new EventHandler(btnClickMe_Click);
        }

		protected void btnClickMe_Click(object sender, EventArgs e)
		{
			// -------------------------------------------------------
			// If i put this code here it will execute properly so long as I call an open and close in the form load.
			// If i do not call an open and close in the load this will still error.
			ShapeFileFeatureLayer streetLayer = new ShapeFileFeatureLayer(Path.Combine(INmapbase, @"Elkhart\IN039lkA.shp"));
			streetLayer.Open();
			DataTable dt1 = streetLayer.QueryTools.ExecuteQuery("Select FENAME From IN039lkA Where FENAME Like('%County Road 17%');");
			DataTable dt2 = streetLayer.QueryTools.ExecuteQuery("Select FENAME From IN039lkA Where FENAME Like('%County Road%');");
			DataTable dt3 = streetLayer.QueryTools.ExecuteQuery("Select FENAME From IN039lkA Where FENAME Like('%County%');");
			streetLayer.Close();
			// -------------------------------------------------------


			MessageBox.Show(String.Format("DT1 count:{0}\nDT2 count:{1}\nDT3 count:{2}", dt1.Rows.Count, dt2.Rows.Count, dt3.Rows.Count));
		}

        protected void Form1_Load(object sender, EventArgs e)
        {
            mapMap.MapUnit = GeographyUnit.DecimalDegree;
            mapMap.ZoomLevelSnapping = ZoomLevelSnappingMode.None;
            mapMap.BackgroundOverlay.BackgroundBrush = new GeoSolidBrush(GeoColor.GeographicColors.Sand);

            string version = WinformsMap.GetVersion();
            if (version != "MapSuiteCore:3.1.299;DesktopEdition:3.1.299")
            {
                throw new Exception("Please verify the reference DLLs and make sure they're 3.1.299");
            }

            ShapeFileFeatureLayer streetLayer = new ShapeFileFeatureLayer(Path.Combine(INmapbase, @"Elkhart\IN039lkA.shp"));
            streetLayer.ZoomLevelSet.ZoomLevel01.DefaultLineStyle = LineStyles.LocalRoad4;
            streetLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            LayerOverlay MapLayerOverlay = new LayerOverlay();
            MapLayerOverlay.Layers.Add("STREETS", streetLayer);
            mapMap.Overlays.Add("MapOverlay", MapLayerOverlay);

            // I can execute this code fine and the button click will still work properly.
            streetLayer.Open();
            mapMap.CurrentExtent = streetLayer.GetBoundingBox();
            streetLayer.Close();

            // If I execute a map.Refresh it apparently causes the lock. If I comment the following line it works. If I execute it causes the error.
            mapMap.Refresh();

			// -------------------------------------------------------
			// This code works fine, and if executed (including the open and close), the click queries will work fine.
			// If I comment the open and close the click queries will fail
			//streetLayer.Open();
			//DataTable dt1 = streetLayer.QueryTools.ExecuteQuery("Select FENAME From IN039lkA Where FENAME Like('%County Road 17%');");
			//DataTable dt2 = streetLayer.QueryTools.ExecuteQuery("Select FENAME From IN039lkA Where FENAME Like('%County Road%');");
			//DataTable dt3 = streetLayer.QueryTools.ExecuteQuery("Select FENAME From IN039lkA Where FENAME Like('%County%');");
			//streetLayer.Close();
			// -------------------------------------------------------

			// -------------------------------------------------------
			// If i execute these commands my click queries work fine.
			streetLayer.Open();
			streetLayer.Close();
			// -------------------------------------------------------
        }
    }
}
